@@ -48,6 +48,6 @@ if __name__ == "__main__":
         tkbot.loop.run_until_complete(get_rstuff())
     except:pass
     
-    logging.info("LETS GOOO THE BOT WORKS")
+    logging.info("i hate kangers; successfully started")
 
     tkbot.run_until_disconnected()
